@@ -77,7 +77,7 @@ class DBLogManager(models.Manager):
                 )
         except Exception, exc:
             try:
-                logger.exception(exc)
+                logger.exception(u'Unable to process log entry: %s' % (exc,))
             except Exception, exc:
                 warnings.warn(u'Unable to process log entry: %s' % (exc,))
         else:
